[gtk+/xi2-for-master] Fix up docs



commit 189c42e12898f198c7dc9e0ea57cbed5abe43f6c
Author: Matthias Clasen <mclasen redhat com>
Date:   Mon May 24 20:18:03 2010 -0400

    Fix up docs
    
    Make sure all symbols are listed, and remove leftover device
    group mentions.

 docs/reference/gdk/gdk3-sections.txt |    9 ++++++
 docs/reference/gtk/gtk3-sections.txt |   48 +++++++++++---------------------
 gdk/gdkdevice.c                      |   50 +++++++++++++++++-----------------
 3 files changed, 50 insertions(+), 57 deletions(-)
---
diff --git a/docs/reference/gdk/gdk3-sections.txt b/docs/reference/gdk/gdk3-sections.txt
index 86c3bc5..fa1dfef 100644
--- a/docs/reference/gdk/gdk3-sections.txt
+++ b/docs/reference/gdk/gdk3-sections.txt
@@ -1034,12 +1034,19 @@ gdk_device_manager_list_devices
 
 <SUBSECTION>
 gdk_device_set_source
+gdk_device_get_source
 gdk_device_set_mode
+gdk_device_get_mode
 gdk_device_set_key
+gdk_device_get_key
 gdk_device_set_axis_use
+gdk_device_get_axis_use
 gdk_device_get_associated_device
 gdk_device_get_device_type
 gdk_device_get_display
+gdk_device_get_has_cursor
+gdk_device_get_n_axes
+gdk_device_get_name
 
 <SUBSECTION>
 gdk_device_grab
@@ -1084,7 +1091,9 @@ GDK_TYPE_DEVICE
 
 <SUBSECTION Private>
 GdkDeviceClass
+GdkDevicePrivate
 GdkDeviceManagerClass
+GdkDeviceManagerPrivate
 gdk_device_get_type
 gdk_device_manager_get_type
 gdk_device_type_get_type
diff --git a/docs/reference/gtk/gtk3-sections.txt b/docs/reference/gtk/gtk3-sections.txt
index 2ea87a1..656155f 100644
--- a/docs/reference/gtk/gtk3-sections.txt
+++ b/docs/reference/gtk/gtk3-sections.txt
@@ -78,10 +78,6 @@ gtk_accelerator_get_label
 gtk_accelerator_set_default_mod_mask
 gtk_accelerator_get_default_mod_mask
 
-<SUBSECTION Private>
-GtkAccelGroupEntry
-gtk_accel_group_get_type
-
 <SUBSECTION Standard>
 GtkAccelGroupClass
 GTK_TYPE_ACCEL_GROUP
@@ -90,6 +86,11 @@ GTK_IS_ACCEL_GROUP
 GTK_ACCEL_GROUP_CLASS
 GTK_IS_ACCEL_GROUP_CLASS
 GTK_ACCEL_GROUP_GET_CLASS
+
+<SUBSECTION Private>
+GtkAccelGroupPrivate
+GtkAccelGroupEntry
+gtk_accel_group_get_type
 </SECTION>
 
 <SECTION>
@@ -141,6 +142,7 @@ GTK_ACCEL_LABEL_CLASS
 GTK_IS_ACCEL_LABEL_CLASS
 GTK_ACCEL_LABEL_GET_CLASS
 <SUBSECTION Private>
+GtkAccelLabelPrivate
 gtk_accel_label_get_type
 </SECTION>
 
@@ -260,13 +262,14 @@ gtk_action_group_add_action_with_accel
 gtk_action_group_remove_action
 GtkActionEntry
 gtk_action_group_add_actions
-gtk_action_group_add_actions_full 
+gtk_action_group_add_actions_full
 GtkToggleActionEntry
 gtk_action_group_add_toggle_actions
-gtk_action_group_add_toggle_actions_full 
+gtk_action_group_add_toggle_actions_full
 GtkRadioActionEntry
 gtk_action_group_add_radio_actions
 gtk_action_group_add_radio_actions_full
+GtkTranslateFunc
 gtk_action_group_set_translate_func
 gtk_action_group_set_translation_domain
 gtk_action_group_translate_string
@@ -4773,8 +4776,6 @@ GtkSelectionData
 GtkWidgetAuxInfo
 GtkWidgetShapeInfo
 GtkWidgetHelpType
-GtkMultiDeviceEvent
-GtkMultiDeviceEventType
 gtk_widget_new
 gtk_widget_destroy
 gtk_widget_destroyed
@@ -4814,15 +4815,18 @@ gtk_widget_set_parent
 gtk_widget_set_parent_window
 gtk_widget_get_parent_window
 gtk_widget_set_events
+gtk_widget_get_events
 gtk_widget_add_events
 gtk_widget_set_extension_events
 gtk_widget_get_extension_events
+gtk_widget_set_device_events
+gtk_widget_get_device_events
+gtk_widget_add_device_events
 gtk_widget_get_toplevel
 gtk_widget_get_ancestor
 gtk_widget_get_colormap
 gtk_widget_set_colormap
 gtk_widget_get_visual
-gtk_widget_get_events
 gtk_widget_get_pointer
 gtk_widget_is_ancestor
 gtk_widget_translate_coordinates
@@ -4941,14 +4945,13 @@ gtk_widget_set_window
 gtk_widget_set_receives_default
 gtk_widget_get_receives_default
 gtk_widget_set_support_multidevice
-gtk_widget_create_device_group
-gtk_widget_remove_device_group
-gtk_widget_get_group_for_device
+gtk_widget_get_support_multidevice
 gtk_widget_set_realized
 gtk_widget_get_realized
 gtk_widget_set_mapped
 gtk_widget_get_mapped
 gtk_widget_get_requisition
+gtk_widget_device_is_shadowed
 
 <SUBSECTION>
 gtk_requisition_copy
@@ -4968,26 +4971,6 @@ gtk_requisition_get_type
 </SECTION>
 
 <SECTION>
-<FILE>gtkdevicegroup</FILE>
-<TITLE>GtkDeviceGroup</TITLE>
-GtkDeviceGroup
-gtk_device_group_add_device
-gtk_device_group_remove_device
-gtk_device_group_get_devices
-
-<SUBSECTION Standard>
-GTK_DEVICE_GROUP
-GTK_DEVICE_GROUP_CLASS
-GTK_DEVICE_GROUP_GET_CLASS
-GTK_IS_DEVICE_GROUP
-GTK_IS_DEVICE_GROUP_CLASS
-GTK_TYPE_DEVICE_GROUP
-
-<SUBSECTION Private>
-gtk_device_group_get_type
-</SECTION>
-
-<SECTION>
 <FILE>gtkwindow</FILE>
 <TITLE>GtkWindow</TITLE>
 GtkWindow
@@ -5232,6 +5215,7 @@ gtk_style_detach
 gtk_style_set_background
 gtk_style_apply_default_background
 gtk_style_lookup_color
+gtk_style_lookup_icon_set
 gtk_style_render_icon
 gtk_style_get_style_property
 gtk_style_get_valist
diff --git a/gdk/gdkdevice.c b/gdk/gdkdevice.c
index 142f63d..6ee68eb 100644
--- a/gdk/gdkdevice.c
+++ b/gdk/gdkdevice.c
@@ -461,7 +461,7 @@ gdk_device_free_history (GdkTimeCoord **events,
 
 /**
  * gdk_device_get_name:
- * @display: a #GdkDisplay
+ * @device: a #GdkDevice
  *
  * Determines the name of the device.
  *
@@ -479,7 +479,7 @@ gdk_device_get_name (GdkDevice *device)
 
 /**
  * gdk_device_get_has_cursor:
- * @display: a #GdkDisplay
+ * @device: a #GdkDevice
  *
  * Determines whether the pointer follows device motion.
  *
@@ -497,7 +497,7 @@ gdk_device_get_has_cursor (GdkDevice *device)
 
 /**
  * gdk_device_get_source:
- * @display: a #GdkDisplay
+ * @device: a #GdkDevice
  *
  * Determines the type of the device.
  *
@@ -531,7 +531,7 @@ gdk_device_set_source (GdkDevice      *device,
 
 /**
  * gdk_device_get_mode:
- * @display: a #GdkDisplay
+ * @device: a #GdkDevice
  *
  * Determines the mode of the device.
  *
@@ -620,25 +620,25 @@ gdk_device_get_key (GdkDevice       *device,
 
 /**
  * gdk_device_set_key:
  * @device: a #GdkDevice.
  * @index: the index of the macro button to set.
  * @keyval: the keyval to generate.
  * @modifiers: the modifiers to set.
  *
  * Specifies the X key event to generate when a macro button of a device
  * is pressed.
  **/
 void
 gdk_device_set_key (GdkDevice      *device,
-		    guint           index,
+		    guint           index_,
 		    guint           keyval,
 		    GdkModifierType modifiers)
 {
   g_return_if_fail (GDK_IS_DEVICE (device));
-  g_return_if_fail (index < device->num_keys);
+  g_return_if_fail (index_ < device->num_keys);
 
-  device->keys[index].keyval = keyval;
-  device->keys[index].modifiers = modifiers;
+  device->keys[index_].keyval = keyval;
+  device->keys[index_].modifiers = modifiers;
 }
 
 /**
@@ -664,44 +664,44 @@ gdk_device_get_axis_use (GdkDevice *device,
 
 /**
  * gdk_device_set_axis_use:
  * @device: a #GdkDevice.
  * @index: the index of the axis.
  * @use: specifies how the axis is used.
  *
  * Specifies how an axis of a device is used.
  **/
 void
 gdk_device_set_axis_use (GdkDevice   *device,
-			 guint        index,
+			 guint        index_,
 			 GdkAxisUse   use)
 {
   GdkDevicePrivate *priv;
   GdkAxisInfo *info;
 
   g_return_if_fail (GDK_IS_DEVICE (device));
-  g_return_if_fail (index < device->num_axes);
+  g_return_if_fail (index_ < device->num_axes);
 
   priv = device->priv;
-  info = &g_array_index (priv->axes, GdkAxisInfo, index);
+  info = &g_array_index (priv->axes, GdkAxisInfo, index_);
   info->use = use;
 
-  device->axes[index].use = use;
+  device->axes[index_].use = use;
 
   switch (use)
     {
     case GDK_AXIS_X:
     case GDK_AXIS_Y:
-      device->axes[index].min = info->min_axis = 0;
-      device->axes[index].max = info->max_axis = 0;
+      device->axes[index_].min = info->min_axis = 0;
+      device->axes[index_].max = info->max_axis = 0;
       break;
     case GDK_AXIS_XTILT:
     case GDK_AXIS_YTILT:
-      device->axes[index].min = info->min_axis = -1;
-      device->axes[index].max = info->max_axis = 1;
+      device->axes[index_].min = info->min_axis = -1;
+      device->axes[index_].max = info->max_axis = 1;
       break;
     default:
-      device->axes[index].min = info->min_axis = 0;
-      device->axes[index].max = info->max_axis = 1;
+      device->axes[index_].min = info->min_axis = 0;
+      device->axes[index_].max = info->max_axis = 1;
       break;
     }
 }
@@ -620,25 +620,25 @@ gdk_device_get_key (GdkDevice       *device,
 /**
  * gdk_device_set_key:
- * @device: a #GdkDevice.
- * @index: the index of the macro button to set.
- * @keyval: the keyval to generate.
- * @modifiers: the modifiers to set.
+ * @device: a #GdkDevice
+ * @index_: the index of the macro button to set
+ * @keyval: the keyval to generate
+ * @modifiers: the modifiers to set
  *
  * Specifies the X key event to generate when a macro button of a device
@@ -664,44 +664,44 @@ gdk_device_get_axis_use (GdkDevice *device,
 /**
  * gdk_device_set_axis_use:
- * @device: a #GdkDevice.
- * @index: the index of the axis.
- * @use: specifies how the axis is used.
+ * @device: a #GdkDevice
+ * @index_: the index of the axis
+ * @use: specifies how the axis is used
  *
  * Specifies how an axis of a device is used.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]